/* **********************************************************
 * Copyright (C) 1998-2000 VMware, Inc.
 * All Rights Reserved
 * **********************************************************/

#ifndef __VMNETINT_H__
#define __VMNETINT_H__


#define INCLUDE_ALLOW_MODULE
#include "includeCheck.h"
#include "driver-config.h"


/* XXX This should not be here --hpreg */
#ifndef KERNEL_VERSION
#   define KERNEL_VERSION(a, b, c) (((a) << 16) + ((b) << 8) + (c))
#endif


/*
 * Hide all kernel compatibility stuff in those macros
 */


#if LINUX_VERSION_CODE < KERNEL_VERSION(2,3,18)
#   if LINUX_VERSION_CODE < KERNEL_VERSION(2,1,30)
       typedef struct {} spinlock_t;
#      define spin_lock_init(lock)
#      define spin_lock(lock)
/* Fool the compiler to avoid an unused variable --hpreg */
#      define spin_lock_irqsave(lock, flags) do { \
   flags = flags;                                 \
} while (0)
#      define spin_unlock(lock)
#      define spin_unlock_irqrestore(lock, flags)
#   else
#      include <asm/spinlock.h>
#   endif
#else
#   include <linux/spinlock.h>
#endif


#ifdef KERNEL_2_1
#   define compat_fop_set_poll(_pFop, _pFunc) do { \
   (_pFop)->poll = (_pFunc);                       \
} while (0)
#else
#   define compat_fop_set_poll(_pFop, _pFunc) do { \
   (_pFop)->select = (_pFunc);                     \
} while (0)
#endif


/* Appeared in 2.3 kernels, and was then back ported to 2.2.18 --hpreg */
#ifndef DECLARE_WAITQUEUE
#   define DECLARE_WAITQUEUE(name, task) struct wait_queue name = {task, NULL,}
#endif


#ifdef KERNEL_2_4_0
#   define compat_fop_set_owner(_pFop) do { \
   (_pFop)->owner = THIS_MODULE;            \
} while (0)
#   define compat_mod_inc_refcount
#   define compat_mod_dec_refcount
#else
#   define compat_fop_set_owner(_pFop)
#   define compat_mod_inc_refcount do { \
   MOD_INC_USE_COUNT;                   \
} while (0)
#   define compat_mod_dec_refcount do { \
   MOD_DEC_USE_COUNT;                   \
} while (0)
#endif


#ifndef KERNEL_2_1
#   define net_device_stats enet_statistics
#endif


#ifndef KERNEL_2_5_2
#   define major(_dev) MAJOR(_dev)
#   define minor(_dev) MINOR(_dev)
#endif


#if defined(KERNEL_2_5_5)
#   define compat_sk_alloc(_pri) sk_alloc(0, _pri, 1, NULL)
#elif defined(KERNEL_2_1)
#   define compat_sk_alloc(_pri) sk_alloc(0, _pri, 1)
#else
#   define compat_sk_alloc(_pri) sk_alloc(_pri)
#endif


#ifndef KERNEL_2_5_5
#   define pte_offset_map(_dir, _address) pte_offset(_dir, _address)
#   define pte_unmap(_pte)
#endif


#ifndef KERNEL_2_4_8
#   define netif_rx_ni(_skb) netif_rx(_skb)
#endif


#endif /* __VMNETINT_H__ */
